==> libreoffice-still-sdk-24.8.5-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor =
[
    [ "ImportDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae2a31904f507d627e34c4dafc014a1e4", null ],
    [ "ServiceArguments", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a3d06cfe5200379fa4e4747d8a121995a", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XDataPilotDataLayoutFieldSupplier", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a913928a723feff172d4b29d2ef6a09f8", null ],
    [ "XDataPilotDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a0baca2202981b4ab95437373faa989f2", null ],
    [ "ColumnGrand", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a945356a5db35aa3fbe31d54aa7f484fb", null ],
    [ "DrillDownOnDoubleClick", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a4b20f8dd1ed15b1db99474a3ec671154", null ],
    [ "GrandTotalName", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#abe5d65ef04ef08a801069e535a077bca", null ],
    [ "IgnoreEmptyRows", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ace7d19505e51c4b5327439f1e20921b0", null ],
    [ "RepeatIfEmpty", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a8751b5c1c6a72ee9b653f57331031e01", null ],
    [ "RowGrand", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae675464887dc01e17644d56edcc0ee02", null ],
    [ "ShowFilterButton", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#aa300fc477d67cc3ef7659a0b61d0ac0d", null ],
    [ "SourceServiceName", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#aba86ebe9a670c3f2e457ba5617c1b5f0", null ]
];

==> libreoffice-still-sdk-25.8.5-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor =
[
    [ "ImportDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae2a31904f507d627e34c4dafc014a1e4", null ],
    [ "ServiceArguments", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a3d06cfe5200379fa4e4747d8a121995a", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XDataPilotDataLayoutFieldSupplier", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a913928a723feff172d4b29d2ef6a09f8", null ],
    [ "XDataPilotDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a0baca2202981b4ab95437373faa989f2", null ],
    [ "ColumnGrand", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a945356a5db35aa3fbe31d54aa7f484fb", null ],
    [ "DrillDownOnDoubleClick", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a4b20f8dd1ed15b1db99474a3ec671154", null ],
    [ "GrandTotalName", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#abe5d65ef04ef08a801069e535a077bca", null ],
    [ "IgnoreEmptyRows", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ace7d19505e51c4b5327439f1e20921b0", null ],
    [ "RepeatIfEmpty", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a8751b5c1c6a72ee9b653f57331031e01", null ],
    [ "RowGrand", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#ae675464887dc01e17644d56edcc0ee02", null ],
    [ "ShowFilterButton", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#aa300fc477d67cc3ef7659a0b61d0ac0d", null ],
    [ "SourceServiceName", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#aba86ebe9a670c3f2e457ba5617c1b5f0", null ]
];
